import os
import sys
from sqlalchemy import engine_from_config
from pyramid.paster import get_appsettings, setup_logging
from clmcservice.models import DBSession, Base


def usage(argv):
    """
    A method to be called when the script has been used in an incorrect way.

    :param argv: cmd arguments
    """

    cmd = os.path.basename(argv[0])
    print('usage: %s <config_uri>\n'
          '(example: "%s development.ini")' % (cmd, cmd))
    sys.exit(1)


def main(argv=sys.argv):
    """
    Main method of the script - initialises the database by creating all tables declared in the models.py module

    :param argv: command line arguments - expects a configuration .ini file from which it retrieves the URL with which to connect to postgresql
    """

    if len(argv) != 2:
        usage(argv)  # in case of wrong usage

    config_uri = argv[1]
    setup_logging(config_uri)

    settings = get_appsettings(config_uri)  # get application specific settings
    engine = engine_from_config(settings, 'sqlalchemy.')  # create the db engine from the sqlalchemy setting configured in the .ini file

    DBSession.configure(bind=engine)
    Base.metadata.create_all(engine)  # creates all model tables
